Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(153)

Unified Diff: src/vm/signal.h

Issue 1659163007: Rename fletch -> dartino (Closed) Base URL: https://github.com/dartino/sdk.git@master
Patch Set: address comments Created 4 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « src/vm/session_no_live_coding.h ('k') | src/vm/snapshot.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/vm/signal.h
diff --git a/src/vm/signal.h b/src/vm/signal.h
index 4ffe4a829ac8f7f24af51afbe059190f2040ec5a..a16e76d9db4304ed9c31660cfa0edc112c77a1d3 100644
--- a/src/vm/signal.h
+++ b/src/vm/signal.h
@@ -13,11 +13,11 @@
#include "src/vm/port.h"
#include "src/vm/process_handle.h"
-namespace fletch {
+namespace dartino {
class Signal : public Refcounted<Signal> {
public:
// Please keep these in sync with lib/fletch/fletch.dart:SignalKind.
enum Kind {
kCompileTimeError,
kTerminated,
@@ -45,6 +45,6 @@ class Signal : public Refcounted<Signal> {
const Kind kind_;
};
-} // namespace fletch
+} // namespace dartino
#endif // SRC_VM_SIGNAL_H_
« no previous file with comments | « src/vm/session_no_live_coding.h ('k') | src/vm/snapshot.h » ('j') | no next file with comments »
@@ -13,11 +13,11 @@
class Signal : public Refcounted<Signal> {
public:
- // Please keep these in sync with lib/fletch/fletch.dart:SignalKind.
+ // Please keep these in sync with lib/dartino/dartino.dart:SignalKind.
enum Kind {
kCompileTimeError,

Powered by Google App Engine
This is Rietveld 408576698